@@ -9,10 +9,12 @@ from weaverbird.pipeline.conditions import (
     Condition,
     ConditionComboAnd,
     ConditionComboOr,
+    DateBoundCondition,
     InclusionCondition,
     MatchCondition,
     NullCondition,
 )
+from weaverbird.pipeline.dates import RelativeDate
 from weaverbird.pipeline.steps import AggregateStep
 
 SQL_COMPARISON_OPERATORS = {
@@ -22,6 +24,8 @@ SQL_COMPARISON_OPERATORS = {
     'le': '<=',
     'gt': '>',
     'ge': '>=',
+    'from': '>=',
+    'until': '<=',
 }
 
 SQL_NULLITY_OPERATORS = {
@@ -67,6 +71,29 @@ def apply_condition(condition: Condition, query: str) -> str:
         query += f"{condition.column} {SQL_MATCH_OPERATORS[condition.operator]} '{condition.value}'"
     elif isinstance(condition, InclusionCondition):
         query += f'{condition.column} {SQL_INCLUSION_OPERATORS[condition.operator]} {str(tuple(condition.value))}'
+
+    elif isinstance(condition, DateBoundCondition):
+
+        value = condition.value
+        if isinstance(value, RelativeDate):
+            if value.operator == 'until':
+                sign = -1
+            elif value.operator == 'from':
+                sign = 1
+            else:
+                raise NotImplementedError
+            value_query_part = f"dateadd({ value.duration }, { sign * value.quantity }, '{ value.date.isoformat() }'::DATE)"
+        else:
+            value_query_part = f"to_timestamp('{ value.isoformat() }')"
+
+        # Remove time info from the column to filter on
+        column = f'to_timestamp({ condition.column })'
+        column_without_time = f"DATE_TRUNC('DAY', { column })"
+        # Do the same with the value to compare it to
+        value_without_time = f"DATE_TRUNC('DAY', { value_query_part })"
+
+        query += f'{ column_without_time } { SQL_COMPARISON_OPERATORS[condition.operator] } { value_without_time }'
+
     elif isinstance(condition, ConditionComboAnd):
         query = apply_condition(condition.and_[0], query)
         for c in condition.and_[1:]:
